############################
# MicroPython
# for GEN2040 Tiny v2
# Author:	goldear.net
# Date:		2024/06/22
# Rev:		01
############################


############################
# import Library
## common
import os
import time
from machine import ADC, Pin, SPI
import sdcard


############################
# TEST
TEST_OUTPUT	= 0
TEST_INPUT	= 0
TEST_ADC	= 0
TEST_SD		= 1


############################
# Config
## SDCard
if TEST_SD == 1:
    # Config
    SPI_ID  = 1
    SPI_RX  = 8
    SPI_CS  = 9
    SPI_SCK = 10
    SPI_TX  = 11
    # Create Instance
    spi  = SPI(SPI_ID, sck=Pin(SPI_SCK), mosi=Pin(SPI_TX), miso=Pin(SPI_RX))
    sd   = sdcard.SDCard(spi, Pin(SPI_CS))
    # Mount SDCard
    OUTPUT_PATH = "/sd"
    os.mount(sd, OUTPUT_PATH)
else:
    pass


############################
# MAIN FUNCTION
def main():

    # init
    COUNT = 0
    Vref = 3.3
    Res  = 65535 # 16bit
    
    if TEST_OUTPUT == 1:
        GPIO_0  = Pin( 0, Pin.OUT)
        GPIO_1  = Pin( 1, Pin.OUT)
        GPIO_4  = Pin( 4, Pin.OUT)
        GPIO_5  = Pin( 5, Pin.OUT)
        GPIO_26 = Pin(26, Pin.OUT)
    elif TEST_INPUT == 1:
        GPIO_0  = Pin( 0, Pin.IN, Pin.PULL_UP)
        GPIO_1  = Pin( 1, Pin.IN, Pin.PULL_UP)
        GPIO_4  = Pin( 4, Pin.IN, Pin.PULL_UP)
        GPIO_5  = Pin( 5, Pin.IN, Pin.PULL_UP)
        GPIO_26 = Pin(26, Pin.IN, Pin.PULL_UP)        
    elif TEST_ADC == 1:
        GPIO_26 = Pin(26, Pin.IN, Pin.PULL_UP)
        ADC0    = ADC(GPIO_26)
        coef    = Vref / Res
    else:
        pass


    while True:
        # TEST_OUTPUT
        if TEST_OUTPUT == 1:
            # LOW
            GPIO_0.value(0)
            GPIO_1.value(0)
            GPIO_4.value(0)
            GPIO_5.value(0)
            GPIO_26.value(0)
            time.sleep(0.5)
            # HIGH
            GPIO_0.value(1)
            GPIO_1.value(1)
            GPIO_4.value(1)
            GPIO_5.value(1)
            GPIO_26.value(1)
            time.sleep(0.5)
        else:
            pass

        # TEST_INPUT
        if TEST_INPUT == 1:
            print(f"GPIO_0:  {GPIO_0.value()}")
            print(f"GPIO_1:  {GPIO_1.value()}")
            print(f"GPIO_4:  {GPIO_4.value()}")
            print(f"GPIO_5:  {GPIO_5.value()}")
            print(f"GPIO_26: {GPIO_26.value()}")
            time.sleep(0.1)

        # TEST_ADC
        if TEST_ADC == 1:
            Vread = ADC0.read_u16()*coef
            print(f"Vread: {Vread:.2f}")
            time.sleep(0.1)
            
        # TEST_SD
        if TEST_SD == 1:
            file_name = f"{OUTPUT_PATH}/2024-6-22.csv"
            with open(file_name, "a", encoding="utf-8") as f:
                f.write(f"{COUNT}: Hello world\n")            
            COUNT = COUNT + 1
            time.sleep(1)
        else:
            pass
        
        print(f"CNT: {COUNT} Hello World!")
        
        
    
if __name__ == "__main__":
    main()




